@@ -1,4 +1,4 @@
-from twilio.rest.resources import InstanceResource, ListResource
+from . import InstanceResource, ListResource
 
 
 class Member(InstanceResource):
